@@ -5,12 +5,14 @@ from types import ModuleType
 from typing import Dict, List, Tuple, Type
 
 import toml
-from pydantic import BaseModel, create_model
+from pydantic import BaseModel, create_model, validator
 
 import fps
 from fps.errors import ConfigError
 from fps.utils import get_pkg_name, get_plugin_name
 
+logger = logging.getLogger("fps")
+
 
 class PluginModel(BaseModel):
     enabled: bool = True
@@ -30,10 +32,21 @@ class FPSConfig(BaseModel):
     description: str = "A fast plugins server"
 
     # plugins
+    enabled_plugins: List[str] = []
     disabled_plugins: List[str] = []
 
+    @validator("enabled_plugins", "disabled_plugins")
+    def plugins_format(cls, plugins):
+        warnings = [p for p in plugins if p.startswith("[") or p.endswith("]")]
+        if warnings:
+            logger.warning(
+                f"Enabled or disabled plugins {warnings} include list delimiter(s), "
+                "it could be due to bad configuration"
+            )
+        return plugins
 
-logger = logging.getLogger("fps")
+    class Config:
+        extra = "forbid"
 
 
 class Config:
@@ -144,29 +157,33 @@ class Config:
 
         config_files = list(OrderedDict.fromkeys(config_files))
 
-        return [f for f in config_files if f and os.path.isfile(f)]
+        return [os.path.abspath(f) for f in config_files if f and os.path.isfile(f)]
 
     @classmethod
-    def register_plugin_name(cls, plugin: ModuleType, name: str = None):
+    def register_plugin_name(
+        cls,
+        plugin: ModuleType,
+        name: str = None,
+    ):
         plugin_name = get_plugin_name(plugin)
         pkg = get_pkg_name(plugin, strip_fps=False)
 
         if not name:
-            pkg_name = get_pkg_name(plugin, strip_fps=False)
-            if pkg_name in cls._pkg2name:
-                name = cls._pkg2name[pkg_name]
+            if pkg in cls._pkg2name:
+                name = cls._pkg2name[pkg]
                 logger.debug(f"Re-using plugins package name '{name}'")
             else:
                 name = get_pkg_name(plugin, strip_fps=True)
                 logger.debug(f"Using default name '{name}' for plugins package '{pkg}'")
-
-        if pkg not in cls._pkg2name:
-            logger.info(f"Registering name '{name}' for plugins package '{pkg}'")
+        else:
+            if pkg not in cls._pkg2name:
+                logger.info(f"Registering name '{name}' for plugins package '{pkg}'")
+                cls._pkg2name[pkg] = name
+            else:
+                raise ConfigError
 
         logger.debug(f"Registering name '{name}' for plugin '{plugin_name}'")
-
         cls._plugin2name[plugin] = name
-        cls._pkg2name[pkg] = name
 
         return name
 
@@ -177,11 +194,6 @@ class Config:
         except KeyError:
             return cls.register_plugin_name(plugin)
 
-    @classmethod
-    def clear_names(cls):
-        cls._plugin2name.clear()
-        cls._pkg2name.clear()
-
     @classmethod
     def from_name(cls, plugin_name):
         configs = [c for n, c in cls._models.values() if n == plugin_name]
@@ -193,6 +205,17 @@ class Config:
         else:
             raise ValueError("Conflict: same name declared in multiple plugins")
 
+    @classmethod
+    def clear_names(cls):
+        cls._plugin2name.clear()
+        cls._pkg2name.clear()
+
+    @classmethod
+    def clear_models(cls):
+        cls._models.clear()
+        cls._based_on.clear()
+        cls._files.clear()
+
 
 def get_config(model: Type[PluginModel]) -> PluginModel:
     return Config(model)
